@@ -85,6 +85,7 @@ OC.L10N.register(
     "No audio" : "Inget ljud",
     "Disable video (v)" : "Inaktivera video (v)",
     "Enable video (v)" : "Aktivera video (v)",
+    "Enable video (v) - Your connection will be briefly interrupted when enabling the video for the first time" : "Aktivera video (v) - Din anslutning får ett kort avbrott när du aktiverar videon för första gången",
     "No Camera" : "Ingen kamera",
     "Screensharing is not supported by your browser." : "Skärmdelning fungerar inte i din nuvarande webbläsare.",
     "Screensharing requires the page to be loaded through HTTPS." : "Skärmdelning kräver HTTPS",
@@ -117,6 +118,7 @@ OC.L10N.register(
     "Close" : "Stäng",
     "Show screen" : "Visa skärm",
     "Enable video" : "Aktivera video",
+    "This is taking longer than expected. Are the media permissions already granted (or rejected)? If yes please restart your browser, as audio and video are failing" : "Det tar längre tid än väntat. Har mediarättigheter redan beviljats (eller avvisats)? Om ja, starta om din webbläsare, eftersom ljud och video misslyckas",
     "Access to microphone & camera is only possible with HTTPS" : "Tillgång till mikrofon och kamera är endast möjligt via HTTPS",
     "Please move your setup to HTTPS" : "Vänligen flytta din inställning till HTTPS",
     "Access to microphone & camera was denied" : "Tillgång till mikrofon och kamera blev nekad",
