@@ -103,6 +103,21 @@ class PageController extends Controller {
 		return $this->index($token);
 	}
 
+	/**
+	 * @PublicPage
+	 * @NoCSRFRequired
+	 * @UseSession
+	 *
+	 * @param string $token
+	 * @param string $password
+	 * @return Response
+	 * @throws HintException
+	 */
+	public function authenticatePassword(string $token, string $password = ''): Response {
+		// This is the entry point from the `/call/{token}` URL which is hardcoded in the server.
+		return $this->index($token, '', $password);
+	}
+
 	/**
 	 * @PublicPage
 	 * @NoCSRFRequired
